@@ -168,5 +168,55 @@ xfce_mkdirhier (const gchar *whole_path,
 
 
 
+/**
+ * xfce_create_shared_thumbnail_path:
+ * @uri        : the uri of the file whose shared thumbnail we want to find.
+ * @size       : the thumbnail size (e.g. normal, large).
+ *
+ * Creates the shared thumbnail path for the file that corresponds to the given @uri
+ * and @size. No checks are made regarding the existence of the thumbnail.
+ *
+ * It is the duty of the caller to free the returned string.
+ *
+ * Return value: a string with the thumbnail path or NULL if the @uri could not be converted to
+ * a local filename.
+ *
+ * Since: 4.17.1
+ **/
+gchar*
+xfce_create_shared_thumbnail_path (const gchar *uri,
+                                   const gchar *size)
+{
+  GChecksum   *checksum;
+  gchar       *dir_uri;
+  gchar       *dir_path;
+  gchar       *name;
+  gchar       *filename;
+  gchar       *thumbnail_path;
+
+  name = g_path_get_basename (uri);
+  dir_uri = g_path_get_dirname (uri);
+  dir_path = g_filename_from_uri (dir_uri, NULL, NULL); /* drop file:// */
+
+  checksum = g_checksum_new (G_CHECKSUM_MD5);
+  g_checksum_update (checksum, (const guchar *) name, strlen (name));
+  filename = g_strconcat (g_checksum_get_string (checksum), ".png", NULL);
+
+  if (dir_path != NULL)
+    thumbnail_path = g_build_filename (dir_path, ".sh_thumbnails", size, filename, NULL);
+  else
+    thumbnail_path = NULL;
+
+  /* free memory */
+  g_free (name);
+  g_free (filename);
+  g_free (dir_uri);
+  g_free (dir_path);
+  g_checksum_free (checksum);
+
+  return thumbnail_path;
+}
+
+
 #define __XFCE_FILEUTILS_C__
 #include <libxfce4util/libxfce4util-aliasdef.c>
